# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/account/v1/account_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+strmprivacy/api/account/v1/account_v1.proto\x12\x1astrmprivacy.api.account.v1\x1a\x1fgoogle/api/field_behavior.proto\"2\n\x18GetAccountDetailsRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\"\xdb\x01\n\x19GetAccountDetailsResponse\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x1e\n\x11max_input_streams\x18\x02 \x01(\x05\x42\x03\xe0\x41\x02\x12\x13\n\x06handle\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x19\n\x0csubscription\x18\x04 \x01(\tB\x03\xe0\x41\x02\x12\x19\n\x0corganization\x18\x05 \x01(\tB\x03\xe0\x41\x02\x12\x1c\n\x0forganization_id\x18\x06 \x01(\tB\x03\xe0\x41\x02\x12\x1d\n\x10internal_user_id\x18\x07 \x01(\tB\x03\xe0\x41\x02\"\x1f\n\x19GetLegacyBillingIdRequest:\x02\x18\x01\"9\n\x1aGetLegacyBillingIdResponse\x12\x17\n\nbilling_id\x18\x01 \x01(\tB\x03\xe0\x41\x02:\x02\x18\x01\"I\n\x1a\x43reateAccountHandleRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x13\n\x06handle\x18\x02 \x01(\tB\x03\xe0\x41\x02\"2\n\x1b\x43reateAccountHandleResponse\x12\x13\n\x06handle\x18\x01 \x01(\tB\x03\xe0\x41\x02\"B\n\x19InitializeCheckoutRequest\x12\x14\n\x07plan_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"7\n\x1aInitializeCheckoutResponse\x12\x19\n\x0c\x63heckout_uri\x18\x01 \x01(\tB\x03\xe0\x41\x02\"R\n\x18GetCheckoutStatusRequest\x12\x14\n\x07user_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12 \n\x13\x63heckout_session_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"+\n\x19GetCheckoutStatusResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\"U\n\x1bSetCheckoutCancelledRequest\x12\x14\n\x07user_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12 \n\x13\x63heckout_session_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"\x1e\n\x1cSetCheckoutCancelledResponse\"7\n\x1fInitializeCustomerPortalRequest\x12\x14\n\x07user_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\"D\n InitializeCustomerPortalResponse\x12 \n\x13\x63ustomer_portal_uri\x18\x01 \x01(\tB\x03\xe0\x41\x02\x32\xcf\x07\n\x0e\x41\x63\x63ountService\x12\x80\x01\n\x11GetAccountDetails\x12\x34.strmprivacy.api.account.v1.GetAccountDetailsRequest\x1a\x35.strmprivacy.api.account.v1.GetAccountDetailsResponse\x12\x83\x01\n\x12GetLegacyBillingId\x12\x35.strmprivacy.api.account.v1.GetLegacyBillingIdRequest\x1a\x36.strmprivacy.api.account.v1.GetLegacyBillingIdResponse\x12\x86\x01\n\x13\x43reateAccountHandle\x12\x36.strmprivacy.api.account.v1.CreateAccountHandleRequest\x1a\x37.strmprivacy.api.account.v1.CreateAccountHandleResponse\x12\x83\x01\n\x12InitializeCheckout\x12\x35.strmprivacy.api.account.v1.InitializeCheckoutRequest\x1a\x36.strmprivacy.api.account.v1.InitializeCheckoutResponse\x12\x80\x01\n\x11GetCheckoutStatus\x12\x34.strmprivacy.api.account.v1.GetCheckoutStatusRequest\x1a\x35.strmprivacy.api.account.v1.GetCheckoutStatusResponse\x12\x95\x01\n\x18InitializeCustomerPortal\x12;.strmprivacy.api.account.v1.InitializeCustomerPortalRequest\x1a<.strmprivacy.api.account.v1.InitializeCustomerPortalResponse\x12\x89\x01\n\x14SetCheckoutCancelled\x12\x37.strmprivacy.api.account.v1.SetCheckoutCancelledRequest\x1a\x38.strmprivacy.api.account.v1.SetCheckoutCancelledResponseBf\n\x1dio.strmprivacy.api.account.v1P\x01ZCgithub.com/strmprivacy/api-definitions-go/v2/api/account/v1;accountb\x06proto3')



_GETACCOUNTDETAILSREQUEST = DESCRIPTOR.message_types_by_name['GetAccountDetailsRequest']
_GETACCOUNTDETAILSRESPONSE = DESCRIPTOR.message_types_by_name['GetAccountDetailsResponse']
_GETLEGACYBILLINGIDREQUEST = DESCRIPTOR.message_types_by_name['GetLegacyBillingIdRequest']
_GETLEGACYBILLINGIDRESPONSE = DESCRIPTOR.message_types_by_name['GetLegacyBillingIdResponse']
_CREATEACCOUNTHANDLEREQUEST = DESCRIPTOR.message_types_by_name['CreateAccountHandleRequest']
_CREATEACCOUNTHANDLERESPONSE = DESCRIPTOR.message_types_by_name['CreateAccountHandleResponse']
_INITIALIZECHECKOUTREQUEST = DESCRIPTOR.message_types_by_name['InitializeCheckoutRequest']
_INITIALIZECHECKOUTRESPONSE = DESCRIPTOR.message_types_by_name['InitializeCheckoutResponse']
_GETCHECKOUTSTATUSREQUEST = DESCRIPTOR.message_types_by_name['GetCheckoutStatusRequest']
_GETCHECKOUTSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['GetCheckoutStatusResponse']
_SETCHECKOUTCANCELLEDREQUEST = DESCRIPTOR.message_types_by_name['SetCheckoutCancelledRequest']
_SETCHECKOUTCANCELLEDRESPONSE = DESCRIPTOR.message_types_by_name['SetCheckoutCancelledResponse']
_INITIALIZECUSTOMERPORTALREQUEST = DESCRIPTOR.message_types_by_name['InitializeCustomerPortalRequest']
_INITIALIZECUSTOMERPORTALRESPONSE = DESCRIPTOR.message_types_by_name['InitializeCustomerPortalResponse']
GetAccountDetailsRequest = _reflection.GeneratedProtocolMessageType('GetAccountDetailsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTDETAILSREQUEST,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.GetAccountDetailsRequest)
  })
_sym_db.RegisterMessage(GetAccountDetailsRequest)

GetAccountDetailsResponse = _reflection.GeneratedProtocolMessageType('GetAccountDetailsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTDETAILSRESPONSE,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.GetAccountDetailsResponse)
  })
_sym_db.RegisterMessage(GetAccountDetailsResponse)

GetLegacyBillingIdRequest = _reflection.GeneratedProtocolMessageType('GetLegacyBillingIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLEGACYBILLINGIDREQUEST,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.GetLegacyBillingIdRequest)
  })
_sym_db.RegisterMessage(GetLegacyBillingIdRequest)

GetLegacyBillingIdResponse = _reflection.GeneratedProtocolMessageType('GetLegacyBillingIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLEGACYBILLINGIDRESPONSE,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.GetLegacyBillingIdResponse)
  })
_sym_db.RegisterMessage(GetLegacyBillingIdResponse)

CreateAccountHandleRequest = _reflection.GeneratedProtocolMessageType('CreateAccountHandleRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTHANDLEREQUEST,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.CreateAccountHandleRequest)
  })
_sym_db.RegisterMessage(CreateAccountHandleRequest)

CreateAccountHandleResponse = _reflection.GeneratedProtocolMessageType('CreateAccountHandleResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTHANDLERESPONSE,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.CreateAccountHandleResponse)
  })
_sym_db.RegisterMessage(CreateAccountHandleResponse)

InitializeCheckoutRequest = _reflection.GeneratedProtocolMessageType('InitializeCheckoutRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITIALIZECHECKOUTREQUEST,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.InitializeCheckoutRequest)
  })
_sym_db.RegisterMessage(InitializeCheckoutRequest)

InitializeCheckoutResponse = _reflection.GeneratedProtocolMessageType('InitializeCheckoutResponse', (_message.Message,), {
  'DESCRIPTOR' : _INITIALIZECHECKOUTRESPONSE,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.InitializeCheckoutResponse)
  })
_sym_db.RegisterMessage(InitializeCheckoutResponse)

GetCheckoutStatusRequest = _reflection.GeneratedProtocolMessageType('GetCheckoutStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCHECKOUTSTATUSREQUEST,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.GetCheckoutStatusRequest)
  })
_sym_db.RegisterMessage(GetCheckoutStatusRequest)

GetCheckoutStatusResponse = _reflection.GeneratedProtocolMessageType('GetCheckoutStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCHECKOUTSTATUSRESPONSE,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.GetCheckoutStatusResponse)
  })
_sym_db.RegisterMessage(GetCheckoutStatusResponse)

SetCheckoutCancelledRequest = _reflection.GeneratedProtocolMessageType('SetCheckoutCancelledRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCHECKOUTCANCELLEDREQUEST,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.SetCheckoutCancelledRequest)
  })
_sym_db.RegisterMessage(SetCheckoutCancelledRequest)

SetCheckoutCancelledResponse = _reflection.GeneratedProtocolMessageType('SetCheckoutCancelledResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETCHECKOUTCANCELLEDRESPONSE,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.SetCheckoutCancelledResponse)
  })
_sym_db.RegisterMessage(SetCheckoutCancelledResponse)

InitializeCustomerPortalRequest = _reflection.GeneratedProtocolMessageType('InitializeCustomerPortalRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITIALIZECUSTOMERPORTALREQUEST,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.InitializeCustomerPortalRequest)
  })
_sym_db.RegisterMessage(InitializeCustomerPortalRequest)

InitializeCustomerPortalResponse = _reflection.GeneratedProtocolMessageType('InitializeCustomerPortalResponse', (_message.Message,), {
  'DESCRIPTOR' : _INITIALIZECUSTOMERPORTALRESPONSE,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.InitializeCustomerPortalResponse)
  })
_sym_db.RegisterMessage(InitializeCustomerPortalResponse)

_ACCOUNTSERVICE = DESCRIPTOR.services_by_name['AccountService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035io.strmprivacy.api.account.v1P\001ZCgithub.com/strmprivacy/api-definitions-go/v2/api/account/v1;account'
  _GETACCOUNTDETAILSREQUEST.fields_by_name['billing_id']._options = None
  _GETACCOUNTDETAILSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['billing_id']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['max_input_streams']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['max_input_streams']._serialized_options = b'\340A\002'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['handle']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['handle']._serialized_options = b'\340A\001'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['subscription']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['subscription']._serialized_options = b'\340A\002'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['organization']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['organization']._serialized_options = b'\340A\002'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['organization_id']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['organization_id']._serialized_options = b'\340A\002'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['internal_user_id']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['internal_user_id']._serialized_options = b'\340A\002'
  _GETLEGACYBILLINGIDREQUEST._options = None
  _GETLEGACYBILLINGIDREQUEST._serialized_options = b'\030\001'
  _GETLEGACYBILLINGIDRESPONSE.fields_by_name['billing_id']._options = None
  _GETLEGACYBILLINGIDRESPONSE.fields_by_name['billing_id']._serialized_options = b'\340A\002'
  _GETLEGACYBILLINGIDRESPONSE._options = None
  _GETLEGACYBILLINGIDRESPONSE._serialized_options = b'\030\001'
  _CREATEACCOUNTHANDLEREQUEST.fields_by_name['billing_id']._options = None
  _CREATEACCOUNTHANDLEREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _CREATEACCOUNTHANDLEREQUEST.fields_by_name['handle']._options = None
  _CREATEACCOUNTHANDLEREQUEST.fields_by_name['handle']._serialized_options = b'\340A\002'
  _CREATEACCOUNTHANDLERESPONSE.fields_by_name['handle']._options = None
  _CREATEACCOUNTHANDLERESPONSE.fields_by_name['handle']._serialized_options = b'\340A\002'
  _INITIALIZECHECKOUTREQUEST.fields_by_name['plan_id']._options = None
  _INITIALIZECHECKOUTREQUEST.fields_by_name['plan_id']._serialized_options = b'\340A\002'
  _INITIALIZECHECKOUTRESPONSE.fields_by_name['checkout_uri']._options = None
  _INITIALIZECHECKOUTRESPONSE.fields_by_name['checkout_uri']._serialized_options = b'\340A\002'
  _GETCHECKOUTSTATUSREQUEST.fields_by_name['user_id']._options = None
  _GETCHECKOUTSTATUSREQUEST.fields_by_name['user_id']._serialized_options = b'\340A\002'
  _GETCHECKOUTSTATUSREQUEST.fields_by_name['checkout_session_id']._options = None
  _GETCHECKOUTSTATUSREQUEST.fields_by_name['checkout_session_id']._serialized_options = b'\340A\002'
  _SETCHECKOUTCANCELLEDREQUEST.fields_by_name['user_id']._options = None
  _SETCHECKOUTCANCELLEDREQUEST.fields_by_name['user_id']._serialized_options = b'\340A\002'
  _SETCHECKOUTCANCELLEDREQUEST.fields_by_name['checkout_session_id']._options = None
  _SETCHECKOUTCANCELLEDREQUEST.fields_by_name['checkout_session_id']._serialized_options = b'\340A\002'
  _INITIALIZECUSTOMERPORTALREQUEST.fields_by_name['user_id']._options = None
  _INITIALIZECUSTOMERPORTALREQUEST.fields_by_name['user_id']._serialized_options = b'\340A\002'
  _INITIALIZECUSTOMERPORTALRESPONSE.fields_by_name['customer_portal_uri']._options = None
  _INITIALIZECUSTOMERPORTALRESPONSE.fields_by_name['customer_portal_uri']._serialized_options = b'\340A\002'
  _GETACCOUNTDETAILSREQUEST._serialized_start=108
  _GETACCOUNTDETAILSREQUEST._serialized_end=158
  _GETACCOUNTDETAILSRESPONSE._serialized_start=161
  _GETACCOUNTDETAILSRESPONSE._serialized_end=380
  _GETLEGACYBILLINGIDREQUEST._serialized_start=382
  _GETLEGACYBILLINGIDREQUEST._serialized_end=413
  _GETLEGACYBILLINGIDRESPONSE._serialized_start=415
  _GETLEGACYBILLINGIDRESPONSE._serialized_end=472
  _CREATEACCOUNTHANDLEREQUEST._serialized_start=474
  _CREATEACCOUNTHANDLEREQUEST._serialized_end=547
  _CREATEACCOUNTHANDLERESPONSE._serialized_start=549
  _CREATEACCOUNTHANDLERESPONSE._serialized_end=599
  _INITIALIZECHECKOUTREQUEST._serialized_start=601
  _INITIALIZECHECKOUTREQUEST._serialized_end=667
  _INITIALIZECHECKOUTRESPONSE._serialized_start=669
  _INITIALIZECHECKOUTRESPONSE._serialized_end=724
  _GETCHECKOUTSTATUSREQUEST._serialized_start=726
  _GETCHECKOUTSTATUSREQUEST._serialized_end=808
  _GETCHECKOUTSTATUSRESPONSE._serialized_start=810
  _GETCHECKOUTSTATUSRESPONSE._serialized_end=853
  _SETCHECKOUTCANCELLEDREQUEST._serialized_start=855
  _SETCHECKOUTCANCELLEDREQUEST._serialized_end=940
  _SETCHECKOUTCANCELLEDRESPONSE._serialized_start=942
  _SETCHECKOUTCANCELLEDRESPONSE._serialized_end=972
  _INITIALIZECUSTOMERPORTALREQUEST._serialized_start=974
  _INITIALIZECUSTOMERPORTALREQUEST._serialized_end=1029
  _INITIALIZECUSTOMERPORTALRESPONSE._serialized_start=1031
  _INITIALIZECUSTOMERPORTALRESPONSE._serialized_end=1099
  _ACCOUNTSERVICE._serialized_start=1102
  _ACCOUNTSERVICE._serialized_end=2077
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/projects/v1/projects_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-strmprivacy/api/projects/v1/projects_v1.proto\x12\x1bstrmprivacy.api.projects.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"\x15\n\x13ListProjectsRequest\"N\n\x14ListProjectsResponse\x12\x36\n\x08projects\x18\x01 \x03(\x0b\x32$.strmprivacy.api.entities.v1.Project\"M\n\x14\x43reateProjectRequest\x12\x35\n\x07project\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.Project\"N\n\x15\x43reateProjectResponse\x12\x35\n\x07project\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.Project\"*\n\x14\x44\x65leteProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"\x17\n\x15\x44\x65leteProjectResponse2\xf6\x02\n\x0fProjectsService\x12s\n\x0cListProjects\x12\x30.strmprivacy.api.projects.v1.ListProjectsRequest\x1a\x31.strmprivacy.api.projects.v1.ListProjectsResponse\x12v\n\rCreateProject\x12\x31.strmprivacy.api.projects.v1.CreateProjectRequest\x1a\x32.strmprivacy.api.projects.v1.CreateProjectResponse\x12v\n\rDeleteProject\x12\x31.strmprivacy.api.projects.v1.DeleteProjectRequest\x1a\x32.strmprivacy.api.projects.v1.DeleteProjectResponseBi\n\x1eio.strmprivacy.api.projects.v1P\x01ZEgithub.com/strmprivacy/api-definitions-go/v2/api/projects/v1;projectsb\x06proto3')



_LISTPROJECTSREQUEST = DESCRIPTOR.message_types_by_name['ListProjectsRequest']
_LISTPROJECTSRESPONSE = DESCRIPTOR.message_types_by_name['ListProjectsResponse']
_CREATEPROJECTREQUEST = DESCRIPTOR.message_types_by_name['CreateProjectRequest']
_CREATEPROJECTRESPONSE = DESCRIPTOR.message_types_by_name['CreateProjectResponse']
_DELETEPROJECTREQUEST = DESCRIPTOR.message_types_by_name['DeleteProjectRequest']
_DELETEPROJECTRESPONSE = DESCRIPTOR.message_types_by_name['DeleteProjectResponse']
ListProjectsRequest = _reflection.GeneratedProtocolMessageType('ListProjectsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROJECTSREQUEST,
  '__module__' : 'strmprivacy.api.projects.v1.projects_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.projects.v1.ListProjectsRequest)
  })
_sym_db.RegisterMessage(ListProjectsRequest)

ListProjectsResponse = _reflection.GeneratedProtocolMessageType('ListProjectsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROJECTSRESPONSE,
  '__module__' : 'strmprivacy.api.projects.v1.projects_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.projects.v1.ListProjectsResponse)
  })
_sym_db.RegisterMessage(ListProjectsResponse)

CreateProjectRequest = _reflection.GeneratedProtocolMessageType('CreateProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTREQUEST,
  '__module__' : 'strmprivacy.api.projects.v1.projects_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.projects.v1.CreateProjectRequest)
  })
_sym_db.RegisterMessage(CreateProjectRequest)

CreateProjectResponse = _reflection.GeneratedProtocolMessageType('CreateProjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTRESPONSE,
  '__module__' : 'strmprivacy.api.projects.v1.projects_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.projects.v1.CreateProjectResponse)
  })
_sym_db.RegisterMessage(CreateProjectResponse)

DeleteProjectRequest = _reflection.GeneratedProtocolMessageType('DeleteProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROJECTREQUEST,
  '__module__' : 'strmprivacy.api.projects.v1.projects_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.projects.v1.DeleteProjectRequest)
  })
_sym_db.RegisterMessage(DeleteProjectRequest)

DeleteProjectResponse = _reflection.GeneratedProtocolMessageType('DeleteProjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROJECTRESPONSE,
  '__module__' : 'strmprivacy.api.projects.v1.projects_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.projects.v1.DeleteProjectResponse)
  })
_sym_db.RegisterMessage(DeleteProjectResponse)

_PROJECTSSERVICE = DESCRIPTOR.services_by_name['ProjectsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036io.strmprivacy.api.projects.v1P\001ZEgithub.com/strmprivacy/api-definitions-go/v2/api/projects/v1;projects'
  _LISTPROJECTSREQUEST._serialized_start=158
  _LISTPROJECTSREQUEST._serialized_end=179
  _LISTPROJECTSRESPONSE._serialized_start=181
  _LISTPROJECTSRESPONSE._serialized_end=259
  _CREATEPROJECTREQUEST._serialized_start=261
  _CREATEPROJECTREQUEST._serialized_end=338
  _CREATEPROJECTRESPONSE._serialized_start=340
  _CREATEPROJECTRESPONSE._serialized_end=418
  _DELETEPROJECTREQUEST._serialized_start=420
  _DELETEPROJECTREQUEST._serialized_end=462
  _DELETEPROJECTRESPONSE._serialized_start=464
  _DELETEPROJECTRESPONSE._serialized_end=487
  _PROJECTSSERVICE._serialized_start=490
  _PROJECTSSERVICE._serialized_end=864
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/key_streams/v1/key_streams.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0strmprivacy/api/key_streams/v1/key_streams.proto\x12\x1estrmprivacy.api.key_streams.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"H\n\x15ListKeyStreamsRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x17\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x03\"U\n\x16ListKeyStreamsResponse\x12;\n\x0bkey_streams\x18\x01 \x03(\x0b\x32&.strmprivacy.api.entities.v1.KeyStream\"R\n\x13GetKeyStreamRequest\x12;\n\x03ref\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KeyStreamRefB\x03\xe0\x41\x02\"R\n\x14GetKeyStreamResponse\x12:\n\nkey_stream\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.KeyStream2\x8f\x02\n\x11KeyStreamsService\x12\x7f\n\x0eListKeyStreams\x12\x35.strmprivacy.api.key_streams.v1.ListKeyStreamsRequest\x1a\x36.strmprivacy.api.key_streams.v1.ListKeyStreamsResponse\x12y\n\x0cGetKeyStream\x12\x33.strmprivacy.api.key_streams.v1.GetKeyStreamRequest\x1a\x34.strmprivacy.api.key_streams.v1.GetKeyStreamResponseBr\n!io.strmprivacy.api.key_streams.v1P\x01ZKgithub.com/strmprivacy/api-definitions-go/v2/api/key_streams/v1;key_streamsb\x06proto3')



_LISTKEYSTREAMSREQUEST = DESCRIPTOR.message_types_by_name['ListKeyStreamsRequest']
_LISTKEYSTREAMSRESPONSE = DESCRIPTOR.message_types_by_name['ListKeyStreamsResponse']
_GETKEYSTREAMREQUEST = DESCRIPTOR.message_types_by_name['GetKeyStreamRequest']
_GETKEYSTREAMRESPONSE = DESCRIPTOR.message_types_by_name['GetKeyStreamResponse']
ListKeyStreamsRequest = _reflection.GeneratedProtocolMessageType('ListKeyStreamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTKEYSTREAMSREQUEST,
  '__module__' : 'strmprivacy.api.key_streams.v1.key_streams_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.key_streams.v1.ListKeyStreamsRequest)
  })
_sym_db.RegisterMessage(ListKeyStreamsRequest)

ListKeyStreamsResponse = _reflection.GeneratedProtocolMessageType('ListKeyStreamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTKEYSTREAMSRESPONSE,
  '__module__' : 'strmprivacy.api.key_streams.v1.key_streams_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.key_streams.v1.ListKeyStreamsResponse)
  })
_sym_db.RegisterMessage(ListKeyStreamsResponse)

GetKeyStreamRequest = _reflection.GeneratedProtocolMessageType('GetKeyStreamRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETKEYSTREAMREQUEST,
  '__module__' : 'strmprivacy.api.key_streams.v1.key_streams_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.key_streams.v1.GetKeyStreamRequest)
  })
_sym_db.RegisterMessage(GetKeyStreamRequest)

GetKeyStreamResponse = _reflection.GeneratedProtocolMessageType('GetKeyStreamResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETKEYSTREAMRESPONSE,
  '__module__' : 'strmprivacy.api.key_streams.v1.key_streams_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.key_streams.v1.GetKeyStreamResponse)
  })
_sym_db.RegisterMessage(GetKeyStreamResponse)

_KEYSTREAMSSERVICE = DESCRIPTOR.services_by_name['KeyStreamsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.strmprivacy.api.key_streams.v1P\001ZKgithub.com/strmprivacy/api-definitions-go/v2/api/key_streams/v1;key_streams'
  _LISTKEYSTREAMSREQUEST.fields_by_name['billing_id']._options = None
  _LISTKEYSTREAMSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTKEYSTREAMSREQUEST.fields_by_name['project_id']._options = None
  _LISTKEYSTREAMSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _GETKEYSTREAMREQUEST.fields_by_name['ref']._options = None
  _GETKEYSTREAMREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _LISTKEYSTREAMSREQUEST._serialized_start=164
  _LISTKEYSTREAMSREQUEST._serialized_end=236
  _LISTKEYSTREAMSRESPONSE._serialized_start=238
  _LISTKEYSTREAMSRESPONSE._serialized_end=323
  _GETKEYSTREAMREQUEST._serialized_start=325
  _GETKEYSTREAMREQUEST._serialized_end=407
  _GETKEYSTREAMRESPONSE._serialized_start=409
  _GETKEYSTREAMRESPONSE._serialized_end=491
  _KEYSTREAMSSERVICE._serialized_start=494
  _KEYSTREAMSSERVICE._serialized_end=765
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/consent_levels/v1/consent_levels_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9strmprivacy/api/consent_levels/v1/consent_levels_v1.proto\x12!strmprivacy.api.consent_levels.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"R\n\x1fListConsentLevelMappingsRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x17\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"t\n ListConsentLevelMappingsResponse\x12P\n\x16\x63onsent_level_mappings\x18\x01 \x03(\x0b\x32\x30.strmprivacy.api.entities.v1.ConsentLevelMapping\"i\n DeleteConsentLevelMappingRequest\x12\x45\n\x03ref\x18\x01 \x01(\x0b\x32\x33.strmprivacy.api.entities.v1.ConsentLevelMappingRefB\x03\xe0\x41\x02\"#\n!DeleteConsentLevelMappingResponse\"s\n CreateConsentLevelMappingRequest\x12O\n\x15\x63onsent_level_mapping\x18\x01 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1.ConsentLevelMapping\"t\n!CreateConsentLevelMappingResponse\x12O\n\x15\x63onsent_level_mapping\x18\x01 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1.ConsentLevelMapping\"f\n\x1dGetConsentLevelMappingRequest\x12\x45\n\x03ref\x18\x01 \x01(\x0b\x32\x33.strmprivacy.api.entities.v1.ConsentLevelMappingRefB\x03\xe0\x41\x02\"q\n\x1eGetConsentLevelMappingResponse\x12O\n\x15\x63onsent_level_mapping\x18\x01 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1.ConsentLevelMapping2\xb5\x05\n\x1b\x43onsentLevelMappingsService\x12\xa3\x01\n\x18ListConsentLevelMappings\x12\x42.strmprivacy.api.consent_levels.v1.ListConsentLevelMappingsRequest\x1a\x43.strmprivacy.api.consent_levels.v1.ListConsentLevelMappingsResponse\x12\x9d\x01\n\x16GetConsentLevelMapping\x12@.strmprivacy.api.consent_levels.v1.GetConsentLevelMappingRequest\x1a\x41.strmprivacy.api.consent_levels.v1.GetConsentLevelMappingResponse\x12\xa6\x01\n\x19\x44\x65leteConsentLevelMapping\x12\x43.strmprivacy.api.consent_levels.v1.DeleteConsentLevelMappingRequest\x1a\x44.strmprivacy.api.consent_levels.v1.DeleteConsentLevelMappingResponse\x12\xa6\x01\n\x19\x43reateConsentLevelMapping\x12\x43.strmprivacy.api.consent_levels.v1.CreateConsentLevelMappingRequest\x1a\x44.strmprivacy.api.consent_levels.v1.CreateConsentLevelMappingResponseB{\n$io.strmprivacy.api.consent_levels.v1P\x01ZQgithub.com/strmprivacy/api-definitions-go/v2/api/consent_levels/v1;consent_levelsb\x06proto3')



_LISTCONSENTLEVELMAPPINGSREQUEST = DESCRIPTOR.message_types_by_name['ListConsentLevelMappingsRequest']
_LISTCONSENTLEVELMAPPINGSRESPONSE = DESCRIPTOR.message_types_by_name['ListConsentLevelMappingsResponse']
_DELETECONSENTLEVELMAPPINGREQUEST = DESCRIPTOR.message_types_by_name['DeleteConsentLevelMappingRequest']
_DELETECONSENTLEVELMAPPINGRESPONSE = DESCRIPTOR.message_types_by_name['DeleteConsentLevelMappingResponse']
_CREATECONSENTLEVELMAPPINGREQUEST = DESCRIPTOR.message_types_by_name['CreateConsentLevelMappingRequest']
_CREATECONSENTLEVELMAPPINGRESPONSE = DESCRIPTOR.message_types_by_name['CreateConsentLevelMappingResponse']
_GETCONSENTLEVELMAPPINGREQUEST = DESCRIPTOR.message_types_by_name['GetConsentLevelMappingRequest']
_GETCONSENTLEVELMAPPINGRESPONSE = DESCRIPTOR.message_types_by_name['GetConsentLevelMappingResponse']
ListConsentLevelMappingsRequest = _reflection.GeneratedProtocolMessageType('ListConsentLevelMappingsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONSENTLEVELMAPPINGSREQUEST,
  '__module__' : 'strmprivacy.api.consent_levels.v1.consent_levels_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.consent_levels.v1.ListConsentLevelMappingsRequest)
  })
_sym_db.RegisterMessage(ListConsentLevelMappingsRequest)

ListConsentLevelMappingsResponse = _reflection.GeneratedProtocolMessageType('ListConsentLevelMappingsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONSENTLEVELMAPPINGSRESPONSE,
  '__module__' : 'strmprivacy.api.consent_levels.v1.consent_levels_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.consent_levels.v1.ListConsentLevelMappingsResponse)
  })
_sym_db.RegisterMessage(ListConsentLevelMappingsResponse)

DeleteConsentLevelMappingRequest = _reflection.GeneratedProtocolMessageType('DeleteConsentLevelMappingRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONSENTLEVELMAPPINGREQUEST,
  '__module__' : 'strmprivacy.api.consent_levels.v1.consent_levels_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.consent_levels.v1.DeleteConsentLevelMappingRequest)
  })
_sym_db.RegisterMessage(DeleteConsentLevelMappingRequest)

DeleteConsentLevelMappingResponse = _reflection.GeneratedProtocolMessageType('DeleteConsentLevelMappingResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONSENTLEVELMAPPINGRESPONSE,
  '__module__' : 'strmprivacy.api.consent_levels.v1.consent_levels_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.consent_levels.v1.DeleteConsentLevelMappingResponse)
  })
_sym_db.RegisterMessage(DeleteConsentLevelMappingResponse)

CreateConsentLevelMappingRequest = _reflection.GeneratedProtocolMessageType('CreateConsentLevelMappingRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONSENTLEVELMAPPINGREQUEST,
  '__module__' : 'strmprivacy.api.consent_levels.v1.consent_levels_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.consent_levels.v1.CreateConsentLevelMappingRequest)
  })
_sym_db.RegisterMessage(CreateConsentLevelMappingRequest)

CreateConsentLevelMappingResponse = _reflection.GeneratedProtocolMessageType('CreateConsentLevelMappingResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONSENTLEVELMAPPINGRESPONSE,
  '__module__' : 'strmprivacy.api.consent_levels.v1.consent_levels_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.consent_levels.v1.CreateConsentLevelMappingResponse)
  })
_sym_db.RegisterMessage(CreateConsentLevelMappingResponse)

GetConsentLevelMappingRequest = _reflection.GeneratedProtocolMessageType('GetConsentLevelMappingRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONSENTLEVELMAPPINGREQUEST,
  '__module__' : 'strmprivacy.api.consent_levels.v1.consent_levels_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.consent_levels.v1.GetConsentLevelMappingRequest)
  })
_sym_db.RegisterMessage(GetConsentLevelMappingRequest)

GetConsentLevelMappingResponse = _reflection.GeneratedProtocolMessageType('GetConsentLevelMappingResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONSENTLEVELMAPPINGRESPONSE,
  '__module__' : 'strmprivacy.api.consent_levels.v1.consent_levels_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.consent_levels.v1.GetConsentLevelMappingResponse)
  })
_sym_db.RegisterMessage(GetConsentLevelMappingResponse)

_CONSENTLEVELMAPPINGSSERVICE = DESCRIPTOR.services_by_name['ConsentLevelMappingsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.strmprivacy.api.consent_levels.v1P\001ZQgithub.com/strmprivacy/api-definitions-go/v2/api/consent_levels/v1;consent_levels'
  _LISTCONSENTLEVELMAPPINGSREQUEST.fields_by_name['billing_id']._options = None
  _LISTCONSENTLEVELMAPPINGSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTCONSENTLEVELMAPPINGSREQUEST.fields_by_name['project_id']._options = None
  _LISTCONSENTLEVELMAPPINGSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _DELETECONSENTLEVELMAPPINGREQUEST.fields_by_name['ref']._options = None
  _DELETECONSENTLEVELMAPPINGREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _GETCONSENTLEVELMAPPINGREQUEST.fields_by_name['ref']._options = None
  _GETCONSENTLEVELMAPPINGREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _LISTCONSENTLEVELMAPPINGSREQUEST._serialized_start=176
  _LISTCONSENTLEVELMAPPINGSREQUEST._serialized_end=258
  _LISTCONSENTLEVELMAPPINGSRESPONSE._serialized_start=260
  _LISTCONSENTLEVELMAPPINGSRESPONSE._serialized_end=376
  _DELETECONSENTLEVELMAPPINGREQUEST._serialized_start=378
  _DELETECONSENTLEVELMAPPINGREQUEST._serialized_end=483
  _DELETECONSENTLEVELMAPPINGRESPONSE._serialized_start=485
  _DELETECONSENTLEVELMAPPINGRESPONSE._serialized_end=520
  _CREATECONSENTLEVELMAPPINGREQUEST._serialized_start=522
  _CREATECONSENTLEVELMAPPINGREQUEST._serialized_end=637
  _CREATECONSENTLEVELMAPPINGRESPONSE._serialized_start=639
  _CREATECONSENTLEVELMAPPINGRESPONSE._serialized_end=755
  _GETCONSENTLEVELMAPPINGREQUEST._serialized_start=757
  _GETCONSENTLEVELMAPPINGREQUEST._serialized_end=859
  _GETCONSENTLEVELMAPPINGRESPONSE._serialized_start=861
  _GETCONSENTLEVELMAPPINGRESPONSE._serialized_end=974
  _CONSENTLEVELMAPPINGSSERVICE._serialized_start=977
  _CONSENTLEVELMAPPINGSSERVICE._serialized_end=1670
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/kafka_clusters/v1/kafka_clusters_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9strmprivacy/api/kafka_clusters/v1/kafka_clusters_v1.proto\x12!strmprivacy.api.kafka_clusters.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"L\n\x18ListKafkaClustersRequest\x12\x17\n\nbilling_id\x18\x01 \x01(\tB\x03\xe0\x41\x03\x12\x17\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x03\"^\n\x19ListKafkaClustersResponse\x12\x41\n\x0ekafka_clusters\x18\x01 \x03(\x0b\x32).strmprivacy.api.entities.v1.KafkaCluster\"\x8d\x01\n\x19\x44\x65leteKafkaClusterRequest\x12\x17\n\nbilling_id\x18\x01 \x01(\tB\x03\xe0\x41\x03\x12>\n\x03ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03\"\x1c\n\x1a\x44\x65leteKafkaClusterResponse\"]\n\x19\x43reateKafkaClusterRequest\x12@\n\rkafka_cluster\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaCluster\"^\n\x1a\x43reateKafkaClusterResponse\x12@\n\rkafka_cluster\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaCluster\"\x8a\x01\n\x16GetKafkaClusterRequest\x12\x17\n\nbilling_id\x18\x01 \x01(\tB\x03\xe0\x41\x03\x12>\n\x03ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03\"[\n\x17GetKafkaClusterResponse\x12@\n\rkafka_cluster\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaCluster2\xda\x04\n\x14KafkaClustersService\x12\x8e\x01\n\x11ListKafkaClusters\x12;.strmprivacy.api.kafka_clusters.v1.ListKafkaClustersRequest\x1a<.strmprivacy.api.kafka_clusters.v1.ListKafkaClustersResponse\x12\x88\x01\n\x0fGetKafkaCluster\x12\x39.strmprivacy.api.kafka_clusters.v1.GetKafkaClusterRequest\x1a:.strmprivacy.api.kafka_clusters.v1.GetKafkaClusterResponse\x12\x91\x01\n\x12\x44\x65leteKafkaCluster\x12<.strmprivacy.api.kafka_clusters.v1.DeleteKafkaClusterRequest\x1a=.strmprivacy.api.kafka_clusters.v1.DeleteKafkaClusterResponse\x12\x91\x01\n\x12\x43reateKafkaCluster\x12<.strmprivacy.api.kafka_clusters.v1.CreateKafkaClusterRequest\x1a=.strmprivacy.api.kafka_clusters.v1.CreateKafkaClusterResponseB{\n$io.strmprivacy.api.kafka_clusters.v1P\x01ZQgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_clusters/v1;kafka_clustersb\x06proto3')



_LISTKAFKACLUSTERSREQUEST = DESCRIPTOR.message_types_by_name['ListKafkaClustersRequest']
_LISTKAFKACLUSTERSRESPONSE = DESCRIPTOR.message_types_by_name['ListKafkaClustersResponse']
_DELETEKAFKACLUSTERREQUEST = DESCRIPTOR.message_types_by_name['DeleteKafkaClusterRequest']
_DELETEKAFKACLUSTERRESPONSE = DESCRIPTOR.message_types_by_name['DeleteKafkaClusterResponse']
_CREATEKAFKACLUSTERREQUEST = DESCRIPTOR.message_types_by_name['CreateKafkaClusterRequest']
_CREATEKAFKACLUSTERRESPONSE = DESCRIPTOR.message_types_by_name['CreateKafkaClusterResponse']
_GETKAFKACLUSTERREQUEST = DESCRIPTOR.message_types_by_name['GetKafkaClusterRequest']
_GETKAFKACLUSTERRESPONSE = DESCRIPTOR.message_types_by_name['GetKafkaClusterResponse']
ListKafkaClustersRequest = _reflection.GeneratedProtocolMessageType('ListKafkaClustersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTKAFKACLUSTERSREQUEST,
  '__module__' : 'strmprivacy.api.kafka_clusters.v1.kafka_clusters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_clusters.v1.ListKafkaClustersRequest)
  })
_sym_db.RegisterMessage(ListKafkaClustersRequest)

ListKafkaClustersResponse = _reflection.GeneratedProtocolMessageType('ListKafkaClustersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTKAFKACLUSTERSRESPONSE,
  '__module__' : 'strmprivacy.api.kafka_clusters.v1.kafka_clusters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_clusters.v1.ListKafkaClustersResponse)
  })
_sym_db.RegisterMessage(ListKafkaClustersResponse)

DeleteKafkaClusterRequest = _reflection.GeneratedProtocolMessageType('DeleteKafkaClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEKAFKACLUSTERREQUEST,
  '__module__' : 'strmprivacy.api.kafka_clusters.v1.kafka_clusters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_clusters.v1.DeleteKafkaClusterRequest)
  })
_sym_db.RegisterMessage(DeleteKafkaClusterRequest)

DeleteKafkaClusterResponse = _reflection.GeneratedProtocolMessageType('DeleteKafkaClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEKAFKACLUSTERRESPONSE,
  '__module__' : 'strmprivacy.api.kafka_clusters.v1.kafka_clusters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_clusters.v1.DeleteKafkaClusterResponse)
  })
_sym_db.RegisterMessage(DeleteKafkaClusterResponse)

CreateKafkaClusterRequest = _reflection.GeneratedProtocolMessageType('CreateKafkaClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEKAFKACLUSTERREQUEST,
  '__module__' : 'strmprivacy.api.kafka_clusters.v1.kafka_clusters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_clusters.v1.CreateKafkaClusterRequest)
  })
_sym_db.RegisterMessage(CreateKafkaClusterRequest)

CreateKafkaClusterResponse = _reflection.GeneratedProtocolMessageType('CreateKafkaClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEKAFKACLUSTERRESPONSE,
  '__module__' : 'strmprivacy.api.kafka_clusters.v1.kafka_clusters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_clusters.v1.CreateKafkaClusterResponse)
  })
_sym_db.RegisterMessage(CreateKafkaClusterResponse)

GetKafkaClusterRequest = _reflection.GeneratedProtocolMessageType('GetKafkaClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETKAFKACLUSTERREQUEST,
  '__module__' : 'strmprivacy.api.kafka_clusters.v1.kafka_clusters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_clusters.v1.GetKafkaClusterRequest)
  })
_sym_db.RegisterMessage(GetKafkaClusterRequest)

GetKafkaClusterResponse = _reflection.GeneratedProtocolMessageType('GetKafkaClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETKAFKACLUSTERRESPONSE,
  '__module__' : 'strmprivacy.api.kafka_clusters.v1.kafka_clusters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_clusters.v1.GetKafkaClusterResponse)
  })
_sym_db.RegisterMessage(GetKafkaClusterResponse)

_KAFKACLUSTERSSERVICE = DESCRIPTOR.services_by_name['KafkaClustersService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.strmprivacy.api.kafka_clusters.v1P\001ZQgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_clusters/v1;kafka_clusters'
  _LISTKAFKACLUSTERSREQUEST.fields_by_name['billing_id']._options = None
  _LISTKAFKACLUSTERSREQUEST.fields_by_name['billing_id']._serialized_options = b'\340A\003'
  _LISTKAFKACLUSTERSREQUEST.fields_by_name['project_id']._options = None
  _LISTKAFKACLUSTERSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['billing_id']._options = None
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['billing_id']._serialized_options = b'\340A\003'
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['ref']._options = None
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['project_id']._options = None
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _GETKAFKACLUSTERREQUEST.fields_by_name['billing_id']._options = None
  _GETKAFKACLUSTERREQUEST.fields_by_name['billing_id']._serialized_options = b'\340A\003'
  _GETKAFKACLUSTERREQUEST.fields_by_name['ref']._options = None
  _GETKAFKACLUSTERREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _GETKAFKACLUSTERREQUEST.fields_by_name['project_id']._options = None
  _GETKAFKACLUSTERREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _LISTKAFKACLUSTERSREQUEST._serialized_start=176
  _LISTKAFKACLUSTERSREQUEST._serialized_end=252
  _LISTKAFKACLUSTERSRESPONSE._serialized_start=254
  _LISTKAFKACLUSTERSRESPONSE._serialized_end=348
  _DELETEKAFKACLUSTERREQUEST._serialized_start=351
  _DELETEKAFKACLUSTERREQUEST._serialized_end=492
  _DELETEKAFKACLUSTERRESPONSE._serialized_start=494
  _DELETEKAFKACLUSTERRESPONSE._serialized_end=522
  _CREATEKAFKACLUSTERREQUEST._serialized_start=524
  _CREATEKAFKACLUSTERREQUEST._serialized_end=617
  _CREATEKAFKACLUSTERRESPONSE._serialized_start=619
  _CREATEKAFKACLUSTERRESPONSE._serialized_end=713
  _GETKAFKACLUSTERREQUEST._serialized_start=716
  _GETKAFKACLUSTERREQUEST._serialized_end=854
  _GETKAFKACLUSTERRESPONSE._serialized_start=856
  _GETKAFKACLUSTERRESPONSE._serialized_end=947
  _KAFKACLUSTERSSERVICE._serialized_start=950
  _KAFKACLUSTERSSERVICE._serialized_end=1552
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/data_contracts/v1/data_contracts_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9strmprivacy/api/data_contracts/v1/data_contracts_v1.proto\x12!strmprivacy.api.data_contracts.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"\xbf\x02\n\x18ListDataContractsRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x13\n\x06\x66ilter\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06handle\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x11\n\x04name\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12M\n\x0epublic_private\x18\x05 \x01(\x0e\x32\x30.strmprivacy.api.entities.v1.FilterPublicPrivateB\x03\xe0\x41\x01\x12\x37\n\x06labels\x18\x07 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelB\x03\xe0\x41\x01\x12\x14\n\x07\x64omains\x18\x08 \x03(\tB\x03\xe0\x41\x01\x12\x17\n\nindustries\x18\t \x03(\tB\x03\xe0\x41\x01\x12\x17\n\nproject_id\x18\n \x01(\tB\x03\xe0\x41\x02\"^\n\x19ListDataContractsResponse\x12\x41\n\x0e\x64\x61ta_contracts\x18\x01 \x03(\x0b\x32).strmprivacy.api.entities.v1.DataContract\"w\n\x16GetDataContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x39\n\x03ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRef\x12\n\n\x02id\x18\x03 \x01(\t\"r\n\x17GetDataContractResponse\x12@\n\rdata_contract\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContract\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x02\"\x89\x01\n\x19\x43reateDataContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12@\n\rdata_contract\x18\x02 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContract\x12\x12\n\nproject_id\x18\x03 \x01(\t\"u\n\x1a\x43reateDataContractResponse\x12@\n\rdata_contract\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContract\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x03\"\xc7\x01\n\x19UpdateDataContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x45\n\rdata_contract\x18\x02 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContractB\x03\xe0\x41\x02\x12\x15\n\x08\x63hecksum\x18\x03 \x01(\tB\x03\xe0\x41\x02\x12\x34\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02\"u\n\x1aUpdateDataContractResponse\x12@\n\rdata_contract\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContract\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x03\"D\n\x19ReviewDataContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x0f\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"\x1c\n\x1aReviewDataContractResponse\"F\n\x1b\x41\x63tivateDataContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x0f\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"\x1e\n\x1c\x41\x63tivateDataContractResponse\"D\n\x19\x44\x65leteDataContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x0f\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"\x1c\n\x1a\x44\x65leteDataContractResponse\"E\n\x1a\x41rchiveDataContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x0f\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"\x1d\n\x1b\x41rchiveDataContractResponse\"\x84\x01\n(ValidateDataContractsMaskedFieldsRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12@\n\rmasked_fields\x18\x02 \x01(\x0b\x32).strmprivacy.api.entities.v1.MaskedFields\"\xc2\x03\n)ValidateDataContractsMaskedFieldsResponse\x12\x62\n\x06\x65rrors\x18\x01 \x03(\x0b\x32R.strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsResponse.Error\x1a\xb0\x02\n\x05\x45rror\x12\x0f\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12L\n\x11\x64\x61ta_contract_ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefB\x03\xe0\x41\x02\x12\x0f\n\x07message\x18\x03 \x01(\t\x12m\n\x06\x65rrors\x18\x04 \x03(\x0b\x32].strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsResponse.Error.FieldError\x1aH\n\nFieldError\x12\x15\n\rfield_pattern\x18\x01 \x01(\t\x12\x12\n\nfield_type\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"b\n GetDataContractSchemaCodeRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x0f\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x15\n\x08language\x18\x03 \x01(\tB\x03\xe0\x41\x02\"V\n!GetDataContractSchemaCodeResponse\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x11\n\tdata_size\x18\x02 \x01(\x03\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"\x81\x01\n&GetDataContractSchemaDefinitionRequest\x12\x14\n\x0c\x63onfluent_id\x18\x01 \x01(\x05\x12\x41\n\x0b\x63luster_ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRef\"=\n\'GetDataContractSchemaDefinitionResponse\x12\x12\n\ndefinition\x18\x01 \x01(\t2\xd8\r\n\x14\x44\x61taContractsService\x12\x8e\x01\n\x11ListDataContracts\x12;.strmprivacy.api.data_contracts.v1.ListDataContractsRequest\x1a<.strmprivacy.api.data_contracts.v1.ListDataContractsResponse\x12\x88\x01\n\x0fGetDataContract\x12\x39.strmprivacy.api.data_contracts.v1.GetDataContractRequest\x1a:.strmprivacy.api.data_contracts.v1.GetDataContractResponse\x12\x91\x01\n\x12\x43reateDataContract\x12<.strmprivacy.api.data_contracts.v1.CreateDataContractRequest\x1a=.strmprivacy.api.data_contracts.v1.CreateDataContractResponse\x12\x91\x01\n\x12UpdateDataContract\x12<.strmprivacy.api.data_contracts.v1.UpdateDataContractRequest\x1a=.strmprivacy.api.data_contracts.v1.UpdateDataContractResponse\x12\x91\x01\n\x12ReviewDataContract\x12<.strmprivacy.api.data_contracts.v1.ReviewDataContractRequest\x1a=.strmprivacy.api.data_contracts.v1.ReviewDataContractResponse\x12\x97\x01\n\x14\x41\x63tivateDataContract\x12>.strmprivacy.api.data_contracts.v1.ActivateDataContractRequest\x1a?.strmprivacy.api.data_contracts.v1.ActivateDataContractResponse\x12\x91\x01\n\x12\x44\x65leteDataContract\x12<.strmprivacy.api.data_contracts.v1.DeleteDataContractRequest\x1a=.strmprivacy.api.data_contracts.v1.DeleteDataContractResponse\x12\x94\x01\n\x13\x41rchiveDataContract\x12=.strmprivacy.api.data_contracts.v1.ArchiveDataContractRequest\x1a>.strmprivacy.api.data_contracts.v1.ArchiveDataContractResponse\x12\xa6\x01\n\x19GetDataContractSchemaCode\x12\x43.strmprivacy.api.data_contracts.v1.GetDataContractSchemaCodeRequest\x1a\x44.strmprivacy.api.data_contracts.v1.GetDataContractSchemaCodeResponse\x12\xb8\x01\n\x1fGetDataContractSchemaDefinition\x12I.strmprivacy.api.data_contracts.v1.GetDataContractSchemaDefinitionRequest\x1aJ.strmprivacy.api.data_contracts.v1.GetDataContractSchemaDefinitionResponse\x12\xbe\x01\n!ValidateDataContractsMaskedFields\x12K.strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsRequest\x1aL.strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsResponseB{\n$io.strmprivacy.api.data_contracts.v1P\x01ZQgithub.com/strmprivacy/api-definitions-go/v2/api/data_contracts/v1;data_contractsb\x06proto3')



_LISTDATACONTRACTSREQUEST = DESCRIPTOR.message_types_by_name['ListDataContractsRequest']
_LISTDATACONTRACTSRESPONSE = DESCRIPTOR.message_types_by_name['ListDataContractsResponse']
_GETDATACONTRACTREQUEST = DESCRIPTOR.message_types_by_name['GetDataContractRequest']
_GETDATACONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['GetDataContractResponse']
_CREATEDATACONTRACTREQUEST = DESCRIPTOR.message_types_by_name['CreateDataContractRequest']
_CREATEDATACONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['CreateDataContractResponse']
_UPDATEDATACONTRACTREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataContractRequest']
_UPDATEDATACONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['UpdateDataContractResponse']
_REVIEWDATACONTRACTREQUEST = DESCRIPTOR.message_types_by_name['ReviewDataContractRequest']
_REVIEWDATACONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['ReviewDataContractResponse']
_ACTIVATEDATACONTRACTREQUEST = DESCRIPTOR.message_types_by_name['ActivateDataContractRequest']
_ACTIVATEDATACONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['ActivateDataContractResponse']
_DELETEDATACONTRACTREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataContractRequest']
_DELETEDATACONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['DeleteDataContractResponse']
_ARCHIVEDATACONTRACTREQUEST = DESCRIPTOR.message_types_by_name['ArchiveDataContractRequest']
_ARCHIVEDATACONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['ArchiveDataContractResponse']
_VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST = DESCRIPTOR.message_types_by_name['ValidateDataContractsMaskedFieldsRequest']
_VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE = DESCRIPTOR.message_types_by_name['ValidateDataContractsMaskedFieldsResponse']
_VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR = _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE.nested_types_by_name['Error']
_VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR_FIELDERROR = _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR.nested_types_by_name['FieldError']
_GETDATACONTRACTSCHEMACODEREQUEST = DESCRIPTOR.message_types_by_name['GetDataContractSchemaCodeRequest']
_GETDATACONTRACTSCHEMACODERESPONSE = DESCRIPTOR.message_types_by_name['GetDataContractSchemaCodeResponse']
_GETDATACONTRACTSCHEMADEFINITIONREQUEST = DESCRIPTOR.message_types_by_name['GetDataContractSchemaDefinitionRequest']
_GETDATACONTRACTSCHEMADEFINITIONRESPONSE = DESCRIPTOR.message_types_by_name['GetDataContractSchemaDefinitionResponse']
ListDataContractsRequest = _reflection.GeneratedProtocolMessageType('ListDataContractsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATACONTRACTSREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ListDataContractsRequest)
  })
_sym_db.RegisterMessage(ListDataContractsRequest)

ListDataContractsResponse = _reflection.GeneratedProtocolMessageType('ListDataContractsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATACONTRACTSRESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ListDataContractsResponse)
  })
_sym_db.RegisterMessage(ListDataContractsResponse)

GetDataContractRequest = _reflection.GeneratedProtocolMessageType('GetDataContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.GetDataContractRequest)
  })
_sym_db.RegisterMessage(GetDataContractRequest)

GetDataContractResponse = _reflection.GeneratedProtocolMessageType('GetDataContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.GetDataContractResponse)
  })
_sym_db.RegisterMessage(GetDataContractResponse)

CreateDataContractRequest = _reflection.GeneratedProtocolMessageType('CreateDataContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATACONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.CreateDataContractRequest)
  })
_sym_db.RegisterMessage(CreateDataContractRequest)

CreateDataContractResponse = _reflection.GeneratedProtocolMessageType('CreateDataContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATACONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.CreateDataContractResponse)
  })
_sym_db.RegisterMessage(CreateDataContractResponse)

UpdateDataContractRequest = _reflection.GeneratedProtocolMessageType('UpdateDataContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATACONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.UpdateDataContractRequest)
  })
_sym_db.RegisterMessage(UpdateDataContractRequest)

UpdateDataContractResponse = _reflection.GeneratedProtocolMessageType('UpdateDataContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATACONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.UpdateDataContractResponse)
  })
_sym_db.RegisterMessage(UpdateDataContractResponse)

ReviewDataContractRequest = _reflection.GeneratedProtocolMessageType('ReviewDataContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _REVIEWDATACONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ReviewDataContractRequest)
  })
_sym_db.RegisterMessage(ReviewDataContractRequest)

ReviewDataContractResponse = _reflection.GeneratedProtocolMessageType('ReviewDataContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _REVIEWDATACONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ReviewDataContractResponse)
  })
_sym_db.RegisterMessage(ReviewDataContractResponse)

ActivateDataContractRequest = _reflection.GeneratedProtocolMessageType('ActivateDataContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEDATACONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ActivateDataContractRequest)
  })
_sym_db.RegisterMessage(ActivateDataContractRequest)

ActivateDataContractResponse = _reflection.GeneratedProtocolMessageType('ActivateDataContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEDATACONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ActivateDataContractResponse)
  })
_sym_db.RegisterMessage(ActivateDataContractResponse)

DeleteDataContractRequest = _reflection.GeneratedProtocolMessageType('DeleteDataContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATACONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.DeleteDataContractRequest)
  })
_sym_db.RegisterMessage(DeleteDataContractRequest)

DeleteDataContractResponse = _reflection.GeneratedProtocolMessageType('DeleteDataContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATACONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.DeleteDataContractResponse)
  })
_sym_db.RegisterMessage(DeleteDataContractResponse)

ArchiveDataContractRequest = _reflection.GeneratedProtocolMessageType('ArchiveDataContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _ARCHIVEDATACONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ArchiveDataContractRequest)
  })
_sym_db.RegisterMessage(ArchiveDataContractRequest)

ArchiveDataContractResponse = _reflection.GeneratedProtocolMessageType('ArchiveDataContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _ARCHIVEDATACONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ArchiveDataContractResponse)
  })
_sym_db.RegisterMessage(ArchiveDataContractResponse)

ValidateDataContractsMaskedFieldsRequest = _reflection.GeneratedProtocolMessageType('ValidateDataContractsMaskedFieldsRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsRequest)
  })
_sym_db.RegisterMessage(ValidateDataContractsMaskedFieldsRequest)

ValidateDataContractsMaskedFieldsResponse = _reflection.GeneratedProtocolMessageType('ValidateDataContractsMaskedFieldsResponse', (_message.Message,), {

  'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {

    'FieldError' : _reflection.GeneratedProtocolMessageType('FieldError', (_message.Message,), {
      'DESCRIPTOR' : _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR_FIELDERROR,
      '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
      # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsResponse.Error.FieldError)
      })
    ,
    'DESCRIPTOR' : _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR,
    '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
    # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsResponse.Error)
    })
  ,
  'DESCRIPTOR' : _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsResponse)
  })
_sym_db.RegisterMessage(ValidateDataContractsMaskedFieldsResponse)
_sym_db.RegisterMessage(ValidateDataContractsMaskedFieldsResponse.Error)
_sym_db.RegisterMessage(ValidateDataContractsMaskedFieldsResponse.Error.FieldError)

GetDataContractSchemaCodeRequest = _reflection.GeneratedProtocolMessageType('GetDataContractSchemaCodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACONTRACTSCHEMACODEREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.GetDataContractSchemaCodeRequest)
  })
_sym_db.RegisterMessage(GetDataContractSchemaCodeRequest)

GetDataContractSchemaCodeResponse = _reflection.GeneratedProtocolMessageType('GetDataContractSchemaCodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACONTRACTSCHEMACODERESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.GetDataContractSchemaCodeResponse)
  })
_sym_db.RegisterMessage(GetDataContractSchemaCodeResponse)

GetDataContractSchemaDefinitionRequest = _reflection.GeneratedProtocolMessageType('GetDataContractSchemaDefinitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACONTRACTSCHEMADEFINITIONREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.GetDataContractSchemaDefinitionRequest)
  })
_sym_db.RegisterMessage(GetDataContractSchemaDefinitionRequest)

GetDataContractSchemaDefinitionResponse = _reflection.GeneratedProtocolMessageType('GetDataContractSchemaDefinitionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACONTRACTSCHEMADEFINITIONRESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.GetDataContractSchemaDefinitionResponse)
  })
_sym_db.RegisterMessage(GetDataContractSchemaDefinitionResponse)

_DATACONTRACTSSERVICE = DESCRIPTOR.services_by_name['DataContractsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.strmprivacy.api.data_contracts.v1P\001ZQgithub.com/strmprivacy/api-definitions-go/v2/api/data_contracts/v1;data_contracts'
  _LISTDATACONTRACTSREQUEST.fields_by_name['billing_id']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTDATACONTRACTSREQUEST.fields_by_name['filter']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTDATACONTRACTSREQUEST.fields_by_name['handle']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['handle']._serialized_options = b'\340A\001'
  _LISTDATACONTRACTSREQUEST.fields_by_name['name']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['name']._serialized_options = b'\340A\001'
  _LISTDATACONTRACTSREQUEST.fields_by_name['public_private']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['public_private']._serialized_options = b'\340A\001'
  _LISTDATACONTRACTSREQUEST.fields_by_name['labels']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['labels']._serialized_options = b'\340A\001'
  _LISTDATACONTRACTSREQUEST.fields_by_name['domains']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['domains']._serialized_options = b'\340A\001'
  _LISTDATACONTRACTSREQUEST.fields_by_name['industries']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['industries']._serialized_options = b'\340A\001'
  _LISTDATACONTRACTSREQUEST.fields_by_name['project_id']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _GETDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _GETDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETDATACONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _GETDATACONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _CREATEDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _CREATEDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _CREATEDATACONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _CREATEDATACONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\003'
  _UPDATEDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _UPDATEDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _UPDATEDATACONTRACTREQUEST.fields_by_name['data_contract']._options = None
  _UPDATEDATACONTRACTREQUEST.fields_by_name['data_contract']._serialized_options = b'\340A\002'
  _UPDATEDATACONTRACTREQUEST.fields_by_name['checksum']._options = None
  _UPDATEDATACONTRACTREQUEST.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _UPDATEDATACONTRACTREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEDATACONTRACTREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATEDATACONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _UPDATEDATACONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\003'
  _REVIEWDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _REVIEWDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _REVIEWDATACONTRACTREQUEST.fields_by_name['id']._options = None
  _REVIEWDATACONTRACTREQUEST.fields_by_name['id']._serialized_options = b'\340A\002'
  _ACTIVATEDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _ACTIVATEDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _ACTIVATEDATACONTRACTREQUEST.fields_by_name['id']._options = None
  _ACTIVATEDATACONTRACTREQUEST.fields_by_name['id']._serialized_options = b'\340A\002'
  _DELETEDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _DELETEDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _DELETEDATACONTRACTREQUEST.fields_by_name['id']._options = None
  _DELETEDATACONTRACTREQUEST.fields_by_name['id']._serialized_options = b'\340A\002'
  _ARCHIVEDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _ARCHIVEDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _ARCHIVEDATACONTRACTREQUEST.fields_by_name['id']._options = None
  _ARCHIVEDATACONTRACTREQUEST.fields_by_name['id']._serialized_options = b'\340A\002'
  _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST.fields_by_name['billing_id']._options = None
  _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR.fields_by_name['id']._options = None
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR.fields_by_name['id']._serialized_options = b'\340A\002'
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR.fields_by_name['data_contract_ref']._options = None
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR.fields_by_name['data_contract_ref']._serialized_options = b'\340A\002'
  _GETDATACONTRACTSCHEMACODEREQUEST.fields_by_name['billing_id']._options = None
  _GETDATACONTRACTSCHEMACODEREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETDATACONTRACTSCHEMACODEREQUEST.fields_by_name['id']._options = None
  _GETDATACONTRACTSCHEMACODEREQUEST.fields_by_name['id']._serialized_options = b'\340A\002'
  _GETDATACONTRACTSCHEMACODEREQUEST.fields_by_name['language']._options = None
  _GETDATACONTRACTSCHEMACODEREQUEST.fields_by_name['language']._serialized_options = b'\340A\002'
  _LISTDATACONTRACTSREQUEST._serialized_start=211
  _LISTDATACONTRACTSREQUEST._serialized_end=530
  _LISTDATACONTRACTSRESPONSE._serialized_start=532
  _LISTDATACONTRACTSRESPONSE._serialized_end=626
  _GETDATACONTRACTREQUEST._serialized_start=628
  _GETDATACONTRACTREQUEST._serialized_end=747
  _GETDATACONTRACTRESPONSE._serialized_start=749
  _GETDATACONTRACTRESPONSE._serialized_end=863
  _CREATEDATACONTRACTREQUEST._serialized_start=866
  _CREATEDATACONTRACTREQUEST._serialized_end=1003
  _CREATEDATACONTRACTRESPONSE._serialized_start=1005
  _CREATEDATACONTRACTRESPONSE._serialized_end=1122
  _UPDATEDATACONTRACTREQUEST._serialized_start=1125
  _UPDATEDATACONTRACTREQUEST._serialized_end=1324
  _UPDATEDATACONTRACTRESPONSE._serialized_start=1326
  _UPDATEDATACONTRACTRESPONSE._serialized_end=1443
  _REVIEWDATACONTRACTREQUEST._serialized_start=1445
  _REVIEWDATACONTRACTREQUEST._serialized_end=1513
  _REVIEWDATACONTRACTRESPONSE._serialized_start=1515
  _REVIEWDATACONTRACTRESPONSE._serialized_end=1543
  _ACTIVATEDATACONTRACTREQUEST._serialized_start=1545
  _ACTIVATEDATACONTRACTREQUEST._serialized_end=1615
  _ACTIVATEDATACONTRACTRESPONSE._serialized_start=1617
  _ACTIVATEDATACONTRACTRESPONSE._serialized_end=1647
  _DELETEDATACONTRACTREQUEST._serialized_start=1649
  _DELETEDATACONTRACTREQUEST._serialized_end=1717
  _DELETEDATACONTRACTRESPONSE._serialized_start=1719
  _DELETEDATACONTRACTRESPONSE._serialized_end=1747
  _ARCHIVEDATACONTRACTREQUEST._serialized_start=1749
  _ARCHIVEDATACONTRACTREQUEST._serialized_end=1818
  _ARCHIVEDATACONTRACTRESPONSE._serialized_start=1820
  _ARCHIVEDATACONTRACTRESPONSE._serialized_end=1849
  _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST._serialized_start=1852
  _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST._serialized_end=1984
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE._serialized_start=1987
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE._serialized_end=2437
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR._serialized_start=2133
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR._serialized_end=2437
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR_FIELDERROR._serialized_start=2365
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR_FIELDERROR._serialized_end=2437
  _GETDATACONTRACTSCHEMACODEREQUEST._serialized_start=2439
  _GETDATACONTRACTSCHEMACODEREQUEST._serialized_end=2537
  _GETDATACONTRACTSCHEMACODERESPONSE._serialized_start=2539
  _GETDATACONTRACTSCHEMACODERESPONSE._serialized_end=2625
  _GETDATACONTRACTSCHEMADEFINITIONREQUEST._serialized_start=2628
  _GETDATACONTRACTSCHEMADEFINITIONREQUEST._serialized_end=2757
  _GETDATACONTRACTSCHEMADEFINITIONRESPONSE._serialized_start=2759
  _GETDATACONTRACTSCHEMADEFINITIONRESPONSE._serialized_end=2820
  _DATACONTRACTSSERVICE._serialized_start=2823
  _DATACONTRACTSSERVICE._serialized_end=4575
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/schemas/v1/schemas_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+strmprivacy/api/schemas/v1/schemas_v1.proto\x12\x1astrmprivacy.api.schemas.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"\xe4\x02\n\x12ListSchemasRequest\x12\x17\n\nbilling_id\x18\x01 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06handle\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x11\n\x04name\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12M\n\x0epublic_private\x18\x05 \x01(\x0e\x32\x30.strmprivacy.api.entities.v1.FilterPublicPrivateB\x03\xe0\x41\x01\x12\x41\n\x0bschema_type\x18\x06 \x01(\x0e\x32\'.strmprivacy.api.entities.v1.SchemaTypeB\x03\xe0\x41\x01\x12\x37\n\x06labels\x18\x07 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelB\x03\xe0\x41\x01\x12\x14\n\x07\x64omains\x18\x08 \x03(\tB\x03\xe0\x41\x01\x12\x17\n\nindustries\x18\t \x03(\tB\x03\xe0\x41\x01\"K\n\x13ListSchemasResponse\x12\x34\n\x07schemas\x18\x01 \x03(\x0b\x32#.strmprivacy.api.entities.v1.Schema\"\xa2\x01\n\x10GetSchemaRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x33\n\x03ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRef\x12\x41\n\x0b\x63luster_ref\x18\x03 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRef\"u\n\x11GetSchemaResponse\x12\x33\n\x06schema\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.Schema\x12\x14\n\x0c\x63onfluent_id\x18\x02 \x01(\x05\x12\x15\n\x08\x63hecksum\x18\x03 \x01(\tB\x03\xe0\x41\x02\"v\n\x13\x43reateSchemaRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x33\n\x06schema\x18\x02 \x01(\x0b\x32#.strmprivacy.api.entities.v1.Schema\x12\x12\n\nproject_id\x18\x03 \x01(\t\"b\n\x14\x43reateSchemaResponse\x12\x33\n\x06schema\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.Schema\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x03\"\xcd\x01\n\x13UpdateSchemaRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x38\n\x06schema\x18\x02 \x01(\x0b\x32#.strmprivacy.api.entities.v1.SchemaB\x03\xe0\x41\x02\x12\x15\n\x08\x63hecksum\x18\x03 \x01(\tB\x03\xe0\x41\x02\x12\x34\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x05 \x01(\tB\x03\xe0\x41\x02\"b\n\x14UpdateSchemaResponse\x12\x33\n\x06schema\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.Schema\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x03\"\x89\x01\n\x15\x41\x63tivateSchemaRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12?\n\nschema_ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\x18\n\x16\x41\x63tivateSchemaResponse\"\x87\x01\n\x13\x44\x65leteSchemaRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12?\n\nschema_ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\x16\n\x14\x44\x65leteSchemaResponse\"\x88\x01\n\x14\x41rchiveSchemaRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12?\n\nschema_ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\x17\n\x15\x41rchiveSchemaResponse\"u\n\x14GetSchemaCodeRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x33\n\x03ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRef\x12\x10\n\x08language\x18\x03 \x01(\t\"J\n\x15GetSchemaCodeResponse\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x11\n\tdata_size\x18\x02 \x01(\x03\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"u\n\x1aGetSchemaDefinitionRequest\x12\x14\n\x0c\x63onfluent_id\x18\x01 \x01(\x05\x12\x41\n\x0b\x63luster_ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRef\"1\n\x1bGetSchemaDefinitionResponse\x12\x12\n\ndefinition\x18\x01 \x01(\t2\xb1\x08\n\x0eSchemasService\x12n\n\x0bListSchemas\x12..strmprivacy.api.schemas.v1.ListSchemasRequest\x1a/.strmprivacy.api.schemas.v1.ListSchemasResponse\x12h\n\tGetSchema\x12,.strmprivacy.api.schemas.v1.GetSchemaRequest\x1a-.strmprivacy.api.schemas.v1.GetSchemaResponse\x12q\n\x0c\x43reateSchema\x12/.strmprivacy.api.schemas.v1.CreateSchemaRequest\x1a\x30.strmprivacy.api.schemas.v1.CreateSchemaResponse\x12q\n\x0cUpdateSchema\x12/.strmprivacy.api.schemas.v1.UpdateSchemaRequest\x1a\x30.strmprivacy.api.schemas.v1.UpdateSchemaResponse\x12t\n\rGetSchemaCode\x12\x30.strmprivacy.api.schemas.v1.GetSchemaCodeRequest\x1a\x31.strmprivacy.api.schemas.v1.GetSchemaCodeResponse\x12w\n\x0e\x41\x63tivateSchema\x12\x31.strmprivacy.api.schemas.v1.ActivateSchemaRequest\x1a\x32.strmprivacy.api.schemas.v1.ActivateSchemaResponse\x12q\n\x0c\x44\x65leteSchema\x12/.strmprivacy.api.schemas.v1.DeleteSchemaRequest\x1a\x30.strmprivacy.api.schemas.v1.DeleteSchemaResponse\x12t\n\rArchiveSchema\x12\x30.strmprivacy.api.schemas.v1.ArchiveSchemaRequest\x1a\x31.strmprivacy.api.schemas.v1.ArchiveSchemaResponse\x12\x86\x01\n\x13GetSchemaDefinition\x12\x36.strmprivacy.api.schemas.v1.GetSchemaDefinitionRequest\x1a\x37.strmprivacy.api.schemas.v1.GetSchemaDefinitionResponseBf\n\x1dio.strmprivacy.api.schemas.v1P\x01ZCgithub.com/strmprivacy/api-definitions-go/v2/api/schemas/v1;schemasb\x06proto3')



_LISTSCHEMASREQUEST = DESCRIPTOR.message_types_by_name['ListSchemasRequest']
_LISTSCHEMASRESPONSE = DESCRIPTOR.message_types_by_name['ListSchemasResponse']
_GETSCHEMAREQUEST = DESCRIPTOR.message_types_by_name['GetSchemaRequest']
_GETSCHEMARESPONSE = DESCRIPTOR.message_types_by_name['GetSchemaResponse']
_CREATESCHEMAREQUEST = DESCRIPTOR.message_types_by_name['CreateSchemaRequest']
_CREATESCHEMARESPONSE = DESCRIPTOR.message_types_by_name['CreateSchemaResponse']
_UPDATESCHEMAREQUEST = DESCRIPTOR.message_types_by_name['UpdateSchemaRequest']
_UPDATESCHEMARESPONSE = DESCRIPTOR.message_types_by_name['UpdateSchemaResponse']
_ACTIVATESCHEMAREQUEST = DESCRIPTOR.message_types_by_name['ActivateSchemaRequest']
_ACTIVATESCHEMARESPONSE = DESCRIPTOR.message_types_by_name['ActivateSchemaResponse']
_DELETESCHEMAREQUEST = DESCRIPTOR.message_types_by_name['DeleteSchemaRequest']
_DELETESCHEMARESPONSE = DESCRIPTOR.message_types_by_name['DeleteSchemaResponse']
_ARCHIVESCHEMAREQUEST = DESCRIPTOR.message_types_by_name['ArchiveSchemaRequest']
_ARCHIVESCHEMARESPONSE = DESCRIPTOR.message_types_by_name['ArchiveSchemaResponse']
_GETSCHEMACODEREQUEST = DESCRIPTOR.message_types_by_name['GetSchemaCodeRequest']
_GETSCHEMACODERESPONSE = DESCRIPTOR.message_types_by_name['GetSchemaCodeResponse']
_GETSCHEMADEFINITIONREQUEST = DESCRIPTOR.message_types_by_name['GetSchemaDefinitionRequest']
_GETSCHEMADEFINITIONRESPONSE = DESCRIPTOR.message_types_by_name['GetSchemaDefinitionResponse']
ListSchemasRequest = _reflection.GeneratedProtocolMessageType('ListSchemasRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCHEMASREQUEST,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.ListSchemasRequest)
  })
_sym_db.RegisterMessage(ListSchemasRequest)

ListSchemasResponse = _reflection.GeneratedProtocolMessageType('ListSchemasResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCHEMASRESPONSE,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.ListSchemasResponse)
  })
_sym_db.RegisterMessage(ListSchemasResponse)

GetSchemaRequest = _reflection.GeneratedProtocolMessageType('GetSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSCHEMAREQUEST,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.GetSchemaRequest)
  })
_sym_db.RegisterMessage(GetSchemaRequest)

GetSchemaResponse = _reflection.GeneratedProtocolMessageType('GetSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSCHEMARESPONSE,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.GetSchemaResponse)
  })
_sym_db.RegisterMessage(GetSchemaResponse)

CreateSchemaRequest = _reflection.GeneratedProtocolMessageType('CreateSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESCHEMAREQUEST,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.CreateSchemaRequest)
  })
_sym_db.RegisterMessage(CreateSchemaRequest)

CreateSchemaResponse = _reflection.GeneratedProtocolMessageType('CreateSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESCHEMARESPONSE,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.CreateSchemaResponse)
  })
_sym_db.RegisterMessage(CreateSchemaResponse)

UpdateSchemaRequest = _reflection.GeneratedProtocolMessageType('UpdateSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESCHEMAREQUEST,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.UpdateSchemaRequest)
  })
_sym_db.RegisterMessage(UpdateSchemaRequest)

UpdateSchemaResponse = _reflection.GeneratedProtocolMessageType('UpdateSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESCHEMARESPONSE,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.UpdateSchemaResponse)
  })
_sym_db.RegisterMessage(UpdateSchemaResponse)

ActivateSchemaRequest = _reflection.GeneratedProtocolMessageType('ActivateSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATESCHEMAREQUEST,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.ActivateSchemaRequest)
  })
_sym_db.RegisterMessage(ActivateSchemaRequest)

ActivateSchemaResponse = _reflection.GeneratedProtocolMessageType('ActivateSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATESCHEMARESPONSE,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.ActivateSchemaResponse)
  })
_sym_db.RegisterMessage(ActivateSchemaResponse)

DeleteSchemaRequest = _reflection.GeneratedProtocolMessageType('DeleteSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESCHEMAREQUEST,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.DeleteSchemaRequest)
  })
_sym_db.RegisterMessage(DeleteSchemaRequest)

DeleteSchemaResponse = _reflection.GeneratedProtocolMessageType('DeleteSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETESCHEMARESPONSE,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.DeleteSchemaResponse)
  })
_sym_db.RegisterMessage(DeleteSchemaResponse)

ArchiveSchemaRequest = _reflection.GeneratedProtocolMessageType('ArchiveSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _ARCHIVESCHEMAREQUEST,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.ArchiveSchemaRequest)
  })
_sym_db.RegisterMessage(ArchiveSchemaRequest)

ArchiveSchemaResponse = _reflection.GeneratedProtocolMessageType('ArchiveSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _ARCHIVESCHEMARESPONSE,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.ArchiveSchemaResponse)
  })
_sym_db.RegisterMessage(ArchiveSchemaResponse)

GetSchemaCodeRequest = _reflection.GeneratedProtocolMessageType('GetSchemaCodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSCHEMACODEREQUEST,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.GetSchemaCodeRequest)
  })
_sym_db.RegisterMessage(GetSchemaCodeRequest)

GetSchemaCodeResponse = _reflection.GeneratedProtocolMessageType('GetSchemaCodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSCHEMACODERESPONSE,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.GetSchemaCodeResponse)
  })
_sym_db.RegisterMessage(GetSchemaCodeResponse)

GetSchemaDefinitionRequest = _reflection.GeneratedProtocolMessageType('GetSchemaDefinitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSCHEMADEFINITIONREQUEST,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.GetSchemaDefinitionRequest)
  })
_sym_db.RegisterMessage(GetSchemaDefinitionRequest)

GetSchemaDefinitionResponse = _reflection.GeneratedProtocolMessageType('GetSchemaDefinitionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSCHEMADEFINITIONRESPONSE,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.GetSchemaDefinitionResponse)
  })
_sym_db.RegisterMessage(GetSchemaDefinitionResponse)

_SCHEMASSERVICE = DESCRIPTOR.services_by_name['SchemasService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035io.strmprivacy.api.schemas.v1P\001ZCgithub.com/strmprivacy/api-definitions-go/v2/api/schemas/v1;schemas'
  _LISTSCHEMASREQUEST.fields_by_name['billing_id']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['billing_id']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['filter']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['handle']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['handle']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['name']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['name']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['public_private']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['public_private']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['schema_type']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['schema_type']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['labels']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['labels']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['domains']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['domains']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['industries']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['industries']._serialized_options = b'\340A\001'
  _GETSCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _GETSCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETSCHEMARESPONSE.fields_by_name['checksum']._options = None
  _GETSCHEMARESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _CREATESCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _CREATESCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _CREATESCHEMARESPONSE.fields_by_name['checksum']._options = None
  _CREATESCHEMARESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\003'
  _UPDATESCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _UPDATESCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _UPDATESCHEMAREQUEST.fields_by_name['schema']._options = None
  _UPDATESCHEMAREQUEST.fields_by_name['schema']._serialized_options = b'\340A\002'
  _UPDATESCHEMAREQUEST.fields_by_name['checksum']._options = None
  _UPDATESCHEMAREQUEST.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _UPDATESCHEMAREQUEST.fields_by_name['update_mask']._options = None
  _UPDATESCHEMAREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATESCHEMAREQUEST.fields_by_name['project_id']._options = None
  _UPDATESCHEMAREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _UPDATESCHEMARESPONSE.fields_by_name['checksum']._options = None
  _UPDATESCHEMARESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\003'
  _ACTIVATESCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _ACTIVATESCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _ACTIVATESCHEMAREQUEST.fields_by_name['schema_ref']._options = None
  _ACTIVATESCHEMAREQUEST.fields_by_name['schema_ref']._serialized_options = b'\340A\002'
  _ACTIVATESCHEMAREQUEST.fields_by_name['project_id']._options = None
  _ACTIVATESCHEMAREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _DELETESCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _DELETESCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _DELETESCHEMAREQUEST.fields_by_name['schema_ref']._options = None
  _DELETESCHEMAREQUEST.fields_by_name['schema_ref']._serialized_options = b'\340A\002'
  _DELETESCHEMAREQUEST.fields_by_name['project_id']._options = None
  _DELETESCHEMAREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _ARCHIVESCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _ARCHIVESCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _ARCHIVESCHEMAREQUEST.fields_by_name['schema_ref']._options = None
  _ARCHIVESCHEMAREQUEST.fields_by_name['schema_ref']._serialized_options = b'\340A\002'
  _ARCHIVESCHEMAREQUEST.fields_by_name['project_id']._options = None
  _ARCHIVESCHEMAREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _GETSCHEMACODEREQUEST.fields_by_name['billing_id']._options = None
  _GETSCHEMACODEREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTSCHEMASREQUEST._serialized_start=190
  _LISTSCHEMASREQUEST._serialized_end=546
  _LISTSCHEMASRESPONSE._serialized_start=548
  _LISTSCHEMASRESPONSE._serialized_end=623
  _GETSCHEMAREQUEST._serialized_start=626
  _GETSCHEMAREQUEST._serialized_end=788
  _GETSCHEMARESPONSE._serialized_start=790
  _GETSCHEMARESPONSE._serialized_end=907
  _CREATESCHEMAREQUEST._serialized_start=909
  _CREATESCHEMAREQUEST._serialized_end=1027
  _CREATESCHEMARESPONSE._serialized_start=1029
  _CREATESCHEMARESPONSE._serialized_end=1127
  _UPDATESCHEMAREQUEST._serialized_start=1130
  _UPDATESCHEMAREQUEST._serialized_end=1335
  _UPDATESCHEMARESPONSE._serialized_start=1337
  _UPDATESCHEMARESPONSE._serialized_end=1435
  _ACTIVATESCHEMAREQUEST._serialized_start=1438
  _ACTIVATESCHEMAREQUEST._serialized_end=1575
  _ACTIVATESCHEMARESPONSE._serialized_start=1577
  _ACTIVATESCHEMARESPONSE._serialized_end=1601
  _DELETESCHEMAREQUEST._serialized_start=1604
  _DELETESCHEMAREQUEST._serialized_end=1739
  _DELETESCHEMARESPONSE._serialized_start=1741
  _DELETESCHEMARESPONSE._serialized_end=1763
  _ARCHIVESCHEMAREQUEST._serialized_start=1766
  _ARCHIVESCHEMAREQUEST._serialized_end=1902
  _ARCHIVESCHEMARESPONSE._serialized_start=1904
  _ARCHIVESCHEMARESPONSE._serialized_end=1927
  _GETSCHEMACODEREQUEST._serialized_start=1929
  _GETSCHEMACODEREQUEST._serialized_end=2046
  _GETSCHEMACODERESPONSE._serialized_start=2048
  _GETSCHEMACODERESPONSE._serialized_end=2122
  _GETSCHEMADEFINITIONREQUEST._serialized_start=2124
  _GETSCHEMADEFINITIONREQUEST._serialized_end=2241
  _GETSCHEMADEFINITIONRESPONSE._serialized_start=2243
  _GETSCHEMADEFINITIONRESPONSE._serialized_end=2292
  _SCHEMASSERVICE._serialized_start=2295
  _SCHEMASSERVICE._serialized_end=3368
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/installations/v1/entities_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2strmprivacy/api/installations/v1/entities_v1.proto\x12 strmprivacy.api.installations.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xec\x01\n\x0cInstallation\x12\x0f\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12R\n\x11installation_type\x18\x02 \x01(\x0e\x32\x32.strmprivacy.api.installations.v1.InstallationTypeB\x03\xe0\x41\x02\x12\x1a\n\x12\x62illing_account_id\x18\x03 \x01(\t\x12[\n\x18installation_credentials\x18\x04 \x01(\x0b\x32\x39.strmprivacy.api.installations.v1.InstallationCredentials\"m\n\x17InstallationCredentials\x12\x16\n\tclient_id\x18\x01 \x01(\tB\x03\xe0\x41\x03\x12\x1a\n\rclient_secret\x18\x02 \x01(\tB\x03\xe0\x41\x03\x12\x1e\n\x11image_pull_secret\x18\x03 \x01(\tB\x03\xe0\x41\x03\"\xbc\x01\n\x12InstalledComponent\x12U\n\x0e\x63omponent_type\x18\x01 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x03\xe0\x41\x02\x12O\n\tinstances\x18\x02 \x03(\x0b\x32<.strmprivacy.api.installations.v1.InstalledComponentInstance\"x\n\x1aInstalledComponentInstance\x12\x0f\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12I\n\x06states\x18\x02 \x03(\x0b\x32\x39.strmprivacy.api.installations.v1.InstalledComponentState\"\xd5\x01\n\x1fInstalledComponentsCurrentState\x12U\n\x0e\x63omponent_type\x18\x01 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x03\xe0\x41\x02\x12[\n\tinstances\x18\x02 \x03(\x0b\x32H.strmprivacy.api.installations.v1.InstalledComponentInstanceCurrentState\"\x83\x01\n&InstalledComponentInstanceCurrentState\x12\x0f\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12H\n\x05state\x18\x02 \x01(\x0b\x32\x39.strmprivacy.api.installations.v1.InstalledComponentState\"\xbc\x01\n\x17InstalledComponentState\x12\x33\n\nstate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03\x12V\n\nstate_type\x18\x02 \x01(\x0e\x32=.strmprivacy.api.installations.v1.InstalledComponentStateTypeB\x03\xe0\x41\x02\x12\x14\n\x07message\x18\x03 \x01(\tB\x03\xe0\x41\x01*e\n\x10InstallationType\x12!\n\x1dINSTALLATION_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04SAAS\x10\x01\x12\x0f\n\x0bSELF_HOSTED\x10\x02\x12\x13\n\x0f\x41WS_MARKETPLACE\x10\x03*\xfb\x01\n\x16InstalledComponentType\x12(\n$INSTALLED_COMPONENT_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x42\x41TCH_JOBS_AGENT\x10\x01\x12\x19\n\x15\x42\x41TCH_EXPORTERS_AGENT\x10\x02\x12\x19\n\x15KAFKA_EXPORTERS_AGENT\x10\x03\x12\x11\n\rSTREAMS_AGENT\x10\x04\x12\x11\n\rEVENT_GATEWAY\x10\x05\x12\x0e\n\nWEB_SOCKET\x10\x06\x12\x19\n\x15\x44\x41TA_CONNECTORS_AGENT\x10\x07\x12\x1a\n\x16\x43ONFLUENT_SCHEMA_PROXY\x10\x08*\x89\x01\n\x1bInstalledComponentStateType\x12.\n*INSTALLED_COMPONENT_STATE_TYPE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bPROVISIONED\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x11\n\rSHUTTING_DOWN\x10\x04\x42x\n#io.strmprivacy.api.installations.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installationsb\x06proto3')

_INSTALLATIONTYPE = DESCRIPTOR.enum_types_by_name['InstallationType']
InstallationType = enum_type_wrapper.EnumTypeWrapper(_INSTALLATIONTYPE)
_INSTALLEDCOMPONENTTYPE = DESCRIPTOR.enum_types_by_name['InstalledComponentType']
InstalledComponentType = enum_type_wrapper.EnumTypeWrapper(_INSTALLEDCOMPONENTTYPE)
_INSTALLEDCOMPONENTSTATETYPE = DESCRIPTOR.enum_types_by_name['InstalledComponentStateType']
InstalledComponentStateType = enum_type_wrapper.EnumTypeWrapper(_INSTALLEDCOMPONENTSTATETYPE)
INSTALLATION_TYPE_UNSPECIFIED = 0
SAAS = 1
SELF_HOSTED = 2
AWS_MARKETPLACE = 3
INSTALLED_COMPONENT_TYPE_UNSPECIFIED = 0
BATCH_JOBS_AGENT = 1
BATCH_EXPORTERS_AGENT = 2
KAFKA_EXPORTERS_AGENT = 3
STREAMS_AGENT = 4
EVENT_GATEWAY = 5
WEB_SOCKET = 6
DATA_CONNECTORS_AGENT = 7
CONFLUENT_SCHEMA_PROXY = 8
INSTALLED_COMPONENT_STATE_TYPE_UNSPECIFIED = 0
PROVISIONED = 1
RUNNING = 2
ERROR = 3
SHUTTING_DOWN = 4


_INSTALLATION = DESCRIPTOR.message_types_by_name['Installation']
_INSTALLATIONCREDENTIALS = DESCRIPTOR.message_types_by_name['InstallationCredentials']
_INSTALLEDCOMPONENT = DESCRIPTOR.message_types_by_name['InstalledComponent']
_INSTALLEDCOMPONENTINSTANCE = DESCRIPTOR.message_types_by_name['InstalledComponentInstance']
_INSTALLEDCOMPONENTSCURRENTSTATE = DESCRIPTOR.message_types_by_name['InstalledComponentsCurrentState']
_INSTALLEDCOMPONENTINSTANCECURRENTSTATE = DESCRIPTOR.message_types_by_name['InstalledComponentInstanceCurrentState']
_INSTALLEDCOMPONENTSTATE = DESCRIPTOR.message_types_by_name['InstalledComponentState']
Installation = _reflection.GeneratedProtocolMessageType('Installation', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLATION,
  '__module__' : 'strmprivacy.api.installations.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.Installation)
  })
_sym_db.RegisterMessage(Installation)

InstallationCredentials = _reflection.GeneratedProtocolMessageType('InstallationCredentials', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLATIONCREDENTIALS,
  '__module__' : 'strmprivacy.api.installations.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.InstallationCredentials)
  })
_sym_db.RegisterMessage(InstallationCredentials)

InstalledComponent = _reflection.GeneratedProtocolMessageType('InstalledComponent', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLEDCOMPONENT,
  '__module__' : 'strmprivacy.api.installations.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.InstalledComponent)
  })
_sym_db.RegisterMessage(InstalledComponent)

InstalledComponentInstance = _reflection.GeneratedProtocolMessageType('InstalledComponentInstance', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLEDCOMPONENTINSTANCE,
  '__module__' : 'strmprivacy.api.installations.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.InstalledComponentInstance)
  })
_sym_db.RegisterMessage(InstalledComponentInstance)

InstalledComponentsCurrentState = _reflection.GeneratedProtocolMessageType('InstalledComponentsCurrentState', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLEDCOMPONENTSCURRENTSTATE,
  '__module__' : 'strmprivacy.api.installations.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.InstalledComponentsCurrentState)
  })
_sym_db.RegisterMessage(InstalledComponentsCurrentState)

InstalledComponentInstanceCurrentState = _reflection.GeneratedProtocolMessageType('InstalledComponentInstanceCurrentState', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLEDCOMPONENTINSTANCECURRENTSTATE,
  '__module__' : 'strmprivacy.api.installations.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.InstalledComponentInstanceCurrentState)
  })
_sym_db.RegisterMessage(InstalledComponentInstanceCurrentState)

InstalledComponentState = _reflection.GeneratedProtocolMessageType('InstalledComponentState', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLEDCOMPONENTSTATE,
  '__module__' : 'strmprivacy.api.installations.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.InstalledComponentState)
  })
_sym_db.RegisterMessage(InstalledComponentState)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.installations.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installations'
  _INSTALLATION.fields_by_name['id']._options = None
  _INSTALLATION.fields_by_name['id']._serialized_options = b'\340A\002'
  _INSTALLATION.fields_by_name['installation_type']._options = None
  _INSTALLATION.fields_by_name['installation_type']._serialized_options = b'\340A\002'
  _INSTALLATIONCREDENTIALS.fields_by_name['client_id']._options = None
  _INSTALLATIONCREDENTIALS.fields_by_name['client_id']._serialized_options = b'\340A\003'
  _INSTALLATIONCREDENTIALS.fields_by_name['client_secret']._options = None
  _INSTALLATIONCREDENTIALS.fields_by_name['client_secret']._serialized_options = b'\340A\003'
  _INSTALLATIONCREDENTIALS.fields_by_name['image_pull_secret']._options = None
  _INSTALLATIONCREDENTIALS.fields_by_name['image_pull_secret']._serialized_options = b'\340A\003'
  _INSTALLEDCOMPONENT.fields_by_name['component_type']._options = None
  _INSTALLEDCOMPONENT.fields_by_name['component_type']._serialized_options = b'\340A\002'
  _INSTALLEDCOMPONENTINSTANCE.fields_by_name['id']._options = None
  _INSTALLEDCOMPONENTINSTANCE.fields_by_name['id']._serialized_options = b'\340A\002'
  _INSTALLEDCOMPONENTSCURRENTSTATE.fields_by_name['component_type']._options = None
  _INSTALLEDCOMPONENTSCURRENTSTATE.fields_by_name['component_type']._serialized_options = b'\340A\002'
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE.fields_by_name['id']._options = None
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE.fields_by_name['id']._serialized_options = b'\340A\002'
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_time']._options = None
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_time']._serialized_options = b'\340A\003'
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_type']._options = None
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_type']._serialized_options = b'\340A\002'
  _INSTALLEDCOMPONENTSTATE.fields_by_name['message']._options = None
  _INSTALLEDCOMPONENTSTATE.fields_by_name['message']._serialized_options = b'\340A\001'
  _INSTALLATIONTYPE._serialized_start=1358
  _INSTALLATIONTYPE._serialized_end=1459
  _INSTALLEDCOMPONENTTYPE._serialized_start=1462
  _INSTALLEDCOMPONENTTYPE._serialized_end=1713
  _INSTALLEDCOMPONENTSTATETYPE._serialized_start=1716
  _INSTALLEDCOMPONENTSTATETYPE._serialized_end=1853
  _INSTALLATION._serialized_start=155
  _INSTALLATION._serialized_end=391
  _INSTALLATIONCREDENTIALS._serialized_start=393
  _INSTALLATIONCREDENTIALS._serialized_end=502
  _INSTALLEDCOMPONENT._serialized_start=505
  _INSTALLEDCOMPONENT._serialized_end=693
  _INSTALLEDCOMPONENTINSTANCE._serialized_start=695
  _INSTALLEDCOMPONENTINSTANCE._serialized_end=815
  _INSTALLEDCOMPONENTSCURRENTSTATE._serialized_start=818
  _INSTALLEDCOMPONENTSCURRENTSTATE._serialized_end=1031
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE._serialized_start=1034
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE._serialized_end=1165
  _INSTALLEDCOMPONENTSTATE._serialized_start=1168
  _INSTALLEDCOMPONENTSTATE._serialized_end=1356
# @@protoc_insertion_point(module_scope)
